==> haskell-indexed-traversable-instances-0.1.2-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-BLyzqhTEJOeI3qg6W4cIbv
key:                  indexed-traversable-instances-0.1.2-BLyzqhTEJOeI3qg6W4cIbv
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  826db4cb9645cf21eac250c246823bfb
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-BLyzqhTEJOeI3qg6W4cIbv

depends:
    OneTuple-0.4.2-K0mu11qtjHA7DLgonuVZZb base-4.17.2.1
    indexed-traversable-0.1.4-KlT0Wrn9TQiIszwKvODAZp
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL
    vector-0.13.2.0-InZif5xbqP17OkTvptfKiM

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-traversable-instances-0.1.2-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-1tWXmDhyIbMCAWg80O7cCI
key:                  indexed-traversable-instances-0.1.2-1tWXmDhyIbMCAWg80O7cCI
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  e048bef357261cbe9e2a5f84b5c36c99
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-1tWXmDhyIbMCAWg80O7cCI

depends:
    OneTuple-0.4.2-H2hq3WX7vAYH5Mde32s1b7 base-4.17.2.1
    indexed-traversable-0.1.4-daDHdCedQd5Buv5VkdtT9
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
